pub enum ShapeGuardError {
LocalWithoutAttachedGraph {
local_id: usize,
},
LocalOutOfBounds {
local_id: usize,
},
MissingMetadata {
key: ValueKey<StdTensorOp>,
},
NonExactShape {
key: ValueKey<StdTensorOp>,
},
}Expand description
Error returned when shape-guard metadata cannot be resolved.
Examples
use tenferro_ops::ShapeGuardError;
let error = ShapeGuardError::LocalWithoutAttachedGraph { local_id: 0 };
assert!(error.to_string().contains("attached graph"));Variants
LocalWithoutAttachedGraph
A local graph value was queried before a graph was attached.
LocalOutOfBounds
A local graph value id is outside the attached graph’s value table.
MissingMetadata
No metadata was registered for the resolved value key.
Fields

key: ValueKey<StdTensorOp>Resolved value key.
NonExactShape
Metadata exists, but at least one axis is only bounded or unknown.
Fields

key: ValueKey<StdTensorOp>Resolved value key.