ExtensionShapeError

Enum ExtensionShapeError 

pub enum ExtensionShapeError {
    InputOutOfBounds {
        family_id: &'static str,
        input: usize,
        input_count: usize,
    },
    AxisOutOfBounds {
        family_id: &'static str,
        input: usize,
        axis: usize,
        rank: usize,
    },
    RankMismatch {
        family_id: &'static str,
        lhs_input: usize,
        lhs_rank: usize,
        rhs_input: usize,
        rhs_rank: usize,
    },
}
Errors produced while extension shape requirements inspect input metadata.

Examples

use tenferro_ops::ExtensionShapeError;

let error = ExtensionShapeError::InputOutOfBounds {
    family_id: "example.v1",
    input: 2,
    input_count: 1,
};
assert!(error.to_string().contains("example.v1"));

Variants



InputOutOfBounds

An input metadata index was outside the supplied input list.

Fields

family_id: &'static str

Stable extension family identifier.

input: usize

Requested input index.

input_count: usize

Number of available inputs.



AxisOutOfBounds

An axis was outside the selected input’s rank.

Fields

family_id: &'static str

Stable extension family identifier.

input: usize

Selected input index.

axis: usize

Requested axis index.

rank: usize

Rank of the selected input.



RankMismatch

Two inputs required to have the same shape had different ranks.

Fields

family_id: &'static str

Stable extension family identifier.

lhs_input: usize

Left-hand input index.

lhs_rank: usize

Left-hand input rank.

rhs_input: usize

Right-hand input index.

rhs_rank: usize

Right-hand input rank.