ShapeExtent

Enum ShapeExtent 

pub enum ShapeExtent<D> {
    Exact(D),
    UpperBound(D),
    Unknown,
}
A dimension expression plus the guarantee it provides.

Exact means the expression is the runtime size. UpperBound means the runtime size is no larger than the expression. Unknown preserves rank when no useful bound is available.

Examples

use tenferro_ops::shape_extent::ShapeExtent;

let extent = ShapeExtent::exact(4usize);
assert_eq!(extent.as_exact(), Some(&4));

Variants



Exact(D)

The dimension expression is exact.



UpperBound(D)

The dimension expression is an upper bound.



Unknown

The dimension is rank-known but otherwise unknown.

Implementations

Source

impl<D> ShapeExtent<D>

pub fn exact(dim: D) -> Self

Construct an exact extent.

Examples
use tenferro_ops::shape_extent::ShapeExtent;

let extent = ShapeExtent::exact(3usize);
assert!(extent.is_exact());
pub fn upper_bound(dim: D) -> Self

Construct an upper-bound extent.

Examples
use tenferro_ops::shape_extent::ShapeExtent;

let extent = ShapeExtent::upper_bound(3usize);
assert!(!extent.is_exact());
pub fn unknown() -> Self

Construct an unknown extent.

Examples
use tenferro_ops::shape_extent::ShapeExtent;

let extent: ShapeExtent<usize> = ShapeExtent::unknown();
assert_eq!(extent.bound_expr(), None);
pub fn is_exact(&self) -> bool

Return true when this extent is exact.

Examples
use tenferro_ops::shape_extent::ShapeExtent;

assert!(ShapeExtent::exact(2usize).is_exact());
assert!(!ShapeExtent::upper_bound(2usize).is_exact());
pub fn as_exact(&self) -> Option<&D>

Return the exact dimension expression, if this extent is exact.

Examples
use tenferro_ops::shape_extent::ShapeExtent;

assert_eq!(ShapeExtent::exact(5usize).as_exact(), Some(&5));
assert_eq!(ShapeExtent::upper_bound(5usize).as_exact(), None);
pub fn bound_expr(&self) -> Option<&D>

Return the known bound expression, if any.

Examples
use tenferro_ops::shape_extent::ShapeExtent;

assert_eq!(ShapeExtent::upper_bound(5usize).bound_expr(), Some(&5));
pub fn map<E>(self, f: impl FnOnce(D) -> E) -> ShapeExtent<E>

Map the contained dimension expression while preserving exactness.

Examples
use tenferro_ops::shape_extent::ShapeExtent;

let extent = ShapeExtent::upper_bound(5usize).map(|dim| dim + 1);
assert_eq!(extent.bound_expr(), Some(&6));