DotGeneralConfig

Struct DotGeneralConfig 

pub struct DotGeneralConfig {
    pub lhs_contracting_dims: Vec<usize>,
    pub rhs_contracting_dims: Vec<usize>,
    pub lhs_batch_dims: Vec<usize>,
    pub rhs_batch_dims: Vec<usize>,
    pub lhs_rank: usize,
    pub rhs_rank: usize,
}
DotGeneral dimension configuration.

The output shape is [lhs_free..., rhs_free..., batch...] (col-major batch-trailing convention). Batch dims have the largest stride so that each batch slice occupies a contiguous block of memory.

Examples

use tenferro_tensor::DotGeneralConfig;

let config = DotGeneralConfig {
    lhs_contracting_dims: vec![1],
    rhs_contracting_dims: vec![0],
    lhs_batch_dims: vec![],
    rhs_batch_dims: vec![],
    lhs_rank: 2,
    rhs_rank: 2,
};

Fields

lhs_contracting_dims: Vec<usize>rhs_contracting_dims: Vec<usize>lhs_batch_dims: Vec<usize>rhs_batch_dims: Vec<usize>lhs_rank: usizerhs_rank: usize

Implementations

Source

impl DotGeneralConfig

pub fn validate_ranks( &self, actual_lhs_rank: usize, actual_rhs_rank: usize, ) -> Result<(), String>

Validate that lhs_rank and rhs_rank match the actual tensor ranks.

Examples
use tenferro_tensor::DotGeneralConfig;

let config = DotGeneralConfig {
    lhs_contracting_dims: vec![1],
    rhs_contracting_dims: vec![0],
    lhs_batch_dims: vec![],
    rhs_batch_dims: vec![],
    lhs_rank: 2,
    rhs_rank: 2,
};
config.validate_ranks(2, 2).unwrap();
pub fn validate_dims(&self) -> Result<(), String>