pub enum ExtensionShapeError {
InputOutOfBounds {
family_id: &'static str,
input: usize,
input_count: usize,
},
AxisOutOfBounds {
family_id: &'static str,
input: usize,
axis: usize,
rank: usize,
},
RankMismatch {
family_id: &'static str,
lhs_input: usize,
lhs_rank: usize,
rhs_input: usize,
rhs_rank: usize,
},
}Expand description
Errors produced while extension shape requirements inspect input metadata.
Examples
use tenferro_ops::ExtensionShapeError;
let error = ExtensionShapeError::InputOutOfBounds {
family_id: "example.v1",
input: 2,
input_count: 1,
};
assert!(error.to_string().contains("example.v1"));Variants
InputOutOfBounds
An input metadata index was outside the supplied input list.
Fields
AxisOutOfBounds
An axis was outside the selected input’s rank.
Fields
RankMismatch
Two inputs required to have the same shape had different ranks.