StdTensorOp

Enum StdTensorOp 

pub enum StdTensorOp {
Show 55 variants Add, Mul, Neg, Conj, DotGeneral(DotGeneralConfig), Transpose { perm: Vec<usize>, }, Reshape { from_shape: Vec<DimExpr>, to_shape: Vec<DimExpr>, }, BroadcastInDim { shape: Vec<DimExpr>, dims: Vec<usize>, }, Convert { from: DType, to: DType, }, Constant { dtype: DType, bytes: Vec<u8>, }, ReduceSum { axes: Vec<usize>, input_shape: Vec<DimExpr>, }, Div, Abs, Sign, Maximum, Minimum, Compare(CompareDir), Select, Clamp, Exp, Log, Sin, Cos, Tanh, Sqrt, Rsqrt, Pow, Expm1, Log1p, ExtractDiag { axis_a: usize, axis_b: usize, }, EmbedDiag { axis_a: usize, axis_b: usize, }, Tril { k: i64, }, Triu { k: i64, }, Gather(GatherConfig), Scatter(ScatterConfig), Slice(SliceConfig), DynamicSlice { slice_sizes: Vec<usize>, }, Pad(PadConfig), NaryEinsum { subscripts: String, n_inputs: usize, }, Concatenate { axis: usize, }, Reverse { axes: Vec<usize>, }, ShapeOf { axis: usize, }, DynamicTruncate { axis: usize, }, PadToMatch { axis: usize, }, ReduceProd { axes: Vec<usize>, input_shape: Vec<DimExpr>, }, ReduceMax { axes: Vec<usize>, input_shape: Vec<DimExpr>, }, ReduceMin { axes: Vec<usize>, input_shape: Vec<DimExpr>, }, Cholesky { input_shape: Vec<DimExpr>, }, Lu { input_shape: Vec<DimExpr>, }, Svd { eps: f64, input_shape: Vec<DimExpr>, }, Qr { input_shape: Vec<DimExpr>, }, Eigh { eps: f64, input_shape: Vec<DimExpr>, }, Eig { input_dtype: DType, input_shape: Vec<DimExpr>, }, TriangularSolve { left_side: bool, lower: bool, transpose_a: bool, unit_diagonal: bool, lhs_shape: Vec<DimExpr>, rhs_shape: Vec<DimExpr>, }, ValidateNonsingular { input_shape: Vec<DimExpr>, },
}

Variants



Add



Mul



Neg



Conj



DotGeneral(DotGeneralConfig)



Transpose

Fields

perm: Vec<usize>


Reshape

Fields

from_shape: Vec<DimExpr>
to_shape: Vec<DimExpr>


BroadcastInDim

Fields

shape: Vec<DimExpr>
dims: Vec<usize>


Convert

Fields

from: DType


Constant

Fields

dtype: DType
bytes: Vec<u8>


ReduceSum

Fields

axes: Vec<usize>
input_shape: Vec<DimExpr>


Div



Abs



Sign



Maximum



Minimum



Compare(CompareDir)



Select



Clamp



Exp



Log



Sin



Cos



Tanh



Sqrt



Rsqrt



Pow



Expm1



Log1p



ExtractDiag

Fields

axis_a: usize
axis_b: usize


EmbedDiag

Fields

axis_a: usize
axis_b: usize


Tril

Fields



Triu

Fields



Gather(GatherConfig)



Scatter(ScatterConfig)



Slice(SliceConfig)



DynamicSlice

Fields

slice_sizes: Vec<usize>


Pad(PadConfig)



NaryEinsum

N-ary einsum kept as a single graph node. Contraction path is optimized at execution time from actual input shapes.

Fields

subscripts: String
n_inputs: usize


Concatenate

Fields

axis: usize


Reverse

Fields

axes: Vec<usize>


ShapeOf

Fields

axis: usize


DynamicTruncate

Fields

axis: usize


PadToMatch

Fields

axis: usize


ReduceProd

Fields

axes: Vec<usize>
input_shape: Vec<DimExpr>


ReduceMax

Fields

axes: Vec<usize>
input_shape: Vec<DimExpr>


ReduceMin

Fields

axes: Vec<usize>
input_shape: Vec<DimExpr>


Cholesky

Fields

input_shape: Vec<DimExpr>


Lu

Fields

input_shape: Vec<DimExpr>


Svd

Fields

eps: f64
input_shape: Vec<DimExpr>


Qr

Fields

input_shape: Vec<DimExpr>


Eigh

Fields

eps: f64
input_shape: Vec<DimExpr>


Eig

Fields

input_dtype: DType
input_shape: Vec<DimExpr>


TriangularSolve

Fields

left_side: bool
lower: bool
transpose_a: bool
unit_diagonal: bool
lhs_shape: Vec<DimExpr>
rhs_shape: Vec<DimExpr>


ValidateNonsingular

Fields

input_shape: Vec<DimExpr>

Implementations

Source

impl StdTensorOp

pub fn constant_f64(value: f64) -> Self

Create an f64 scalar constant op.

Examples
use tenferro_ops::std_tensor_op::StdTensorOp;

let op = StdTensorOp::constant_f64(1.5);
pub fn constant_f32(value: f32) -> Self

Create an f32 scalar constant op.

Examples
use tenferro_ops::std_tensor_op::StdTensorOp;

let op = StdTensorOp::constant_f32(1.5_f32);
pub fn constant_c64(value: Complex64) -> Self

Create a Complex64 scalar constant op.

Examples
use num_complex::Complex64;
use tenferro_ops::std_tensor_op::StdTensorOp;

let op = StdTensorOp::constant_c64(Complex64::new(1.0, -2.0));
pub fn constant_c32(value: Complex32) -> Self

Create a Complex32 scalar constant op.

Examples
use num_complex::Complex32;
use tenferro_ops::std_tensor_op::StdTensorOp;

let op = StdTensorOp::constant_c32(Complex32::new(1.0, -2.0));